Helpviewer/HelpDocsInstaller.py

changeset 3670
f0cb7579c0b4
parent 3656
441956d8fce5
child 3992
537d57307ba8
--- a/Helpviewer/HelpDocsInstaller.py	Sat Jul 05 11:41:14 2014 +0200
+++ b/Helpviewer/HelpDocsInstaller.py	Sat Jul 05 12:13:23 2014 +0200
@@ -14,7 +14,7 @@
     QLibraryInfo, QFileInfo
 from PyQt5.QtHelp import QHelpEngineCore
 
-from eric5config import getConfig
+from eric6config import getConfig
 
 
 class HelpDocsInstaller(QThread):
@@ -85,7 +85,7 @@
                     return
                 self.__mutex.unlock()
         
-        changes |= self.__installEric5Doc(engine)
+        changes |= self.__installEric6Doc(engine)
         engine = None
         del engine
         self.docsInstalled.emit(changes)
@@ -164,14 +164,14 @@
         
         return False
     
-    def __installEric5Doc(self, engine):
+    def __installEric6Doc(self, engine):
         """
         Private method to install/update the eric5 help documentation.
         
         @param engine reference to the help engine (QHelpEngineCore)
         @return flag indicating success (boolean)
         """
-        versionKey = "eric5_ide"
+        versionKey = "eric6_ide"
         info = engine.customValue(versionKey, "")
         lst = info.split('|')
         
@@ -164,14 +164,14 @@
         """
-        Private method to install/update the eric5 help documentation.
+        Private method to install/update the eric6 help documentation.
         
         @param engine reference to the help engine (QHelpEngineCore)

eric ide

mercurial